@@ -17,11 +17,10 @@
 # Written by:
 #
 #   Marvin N. Wright
-# Institut fuer Medizinische Biometrie und Statistik
-# Universitaet zu Luebeck
+# Institut für Medizinische Biometrie und Statistik
+# Universität zu Lübeck
 # Ratzeburger Allee 160
-# 23562 Luebeck
-# Germany
+# 23562 Lübeck
 #
 # http://www.imbs-luebeck.de
 # wright@imbs.uni-luebeck.de
@@ -32,9 +31,9 @@
 ##' @title Ranger prediction
 ##' @param object Ranger \code{ranger.forest} object.
 ##' @param data New test data of class \code{data.frame} or \code{gwaa.data} (GenABEL).
-##' @param predict.all Return a matrix with individual predictions for each tree instead of aggregated predictions for all trees (classification and regression only).
 ##' @param seed Random seed used in Ranger.
 ##' @param num.threads Number of threads. Default is number of CPUs available.
+##' @param memory.mode Memory mode, one of 'double', 'float', 'char'.
 ##' @param verbose Verbose output on or off.
 ##' @param ... further arguments passed to or from other methods.
 ##' @return Object of class \code{ranger.prediction} with elements
@@ -51,12 +50,11 @@
 ##' @seealso \code{\link{ranger}}
 ##' @author Marvin N. Wright
 ##' @export
-predict.ranger.forest <- function(object, data, predict.all = FALSE,
-                                  seed = NULL, num.threads = NULL,
-                                  verbose = TRUE, ...) {
+predict.ranger.forest <- function(object, data, seed = NULL, num.threads = NULL,
+                                   memory.mode = "double", verbose = TRUE, ...) {
   
   ## GenABEL GWA data
-  if ("gwaa.data" %in% class(data)) {
+  if (class(data) == "gwaa.data") {
     snp.names <- snp.names(data)
     sparse.data <- data@gtdata@gtps@.Data
     data <- data@phdata[, -1]
@@ -65,7 +63,7 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
   } else {
     sparse.data <- as.matrix(0)
     gwa.mode <- FALSE
-    variable.names <- colnames(data)
+    variable.names <- names(data)
   }
 
   ## Check forest argument
@@ -84,60 +82,22 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
                                          is.null(forest$chf) | is.null(forest$unique.death.times))) {
     stop("Error: Invalid forest object.")
   }
-  
-  ## If alternative interface used, don't subset data
+  if (forest$treetype == "Classification" & (is.null(forest$levels))) {
+    stop("Error: Invalid forest object.")
+  }
+
+  if (sum(!(forest$independent.variable.names %in% variable.names)) > 0) {
+    stop("Error: One or more independent variables not found in data.")
+  }
+  data.selected <- subset(data, select = forest$independent.variable.names)
   if (forest$treetype == "Survival") {
-    if (forest$dependent.varID > 0 & forest$status.varID > 1) {
-      if (!is.matrix(data)) {
-        ## Recode characters
-        char.columns <- sapply(data, is.character)
-        data[char.columns] <- lapply(data[char.columns], factor)
-      }
-      data.final <- data.matrix(data)
-    } else {
-      data.selected <- subset(data, select = forest$independent.variable.names)
-      if (!is.matrix(data.selected)) {
-        ## Recode characters
-        char.columns <- sapply(data.selected, is.character)
-        data.selected[char.columns] <- lapply(data.selected[char.columns], factor)
-      }
-      data.final <- data.matrix(cbind(0, 0, data.selected))
-      variable.names <- c("time", "status", forest$independent.variable.names)
-    }
+    data.final <- data.matrix(cbind(0, 0, data.selected))
+    variable.names <- c("time", "status", forest$independent.variable.names)
   } else {
-    if (ncol(data) == length(forest$independent.variable.names)+1 & forest$dependent.varID > 0) {
-      if (!is.matrix(data)) {
-        ## Recode characters
-        char.columns <- sapply(data, is.character)
-        data[char.columns] <- lapply(data[char.columns], factor)
-      }
-      data.final <- data.matrix(data)
-    } else {
-      data.selected <- subset(data, select = forest$independent.variable.names)
-      if (!is.matrix(data.selected)) {
-        ## Recode characters
-        char.columns <- sapply(data.selected, is.character)
-        data.selected[char.columns] <- lapply(data.selected[char.columns], factor)
-      }
-      ## Arange data as in original data
-      if (forest$dependent.varID == 0) {
-        data.final <- data.matrix(cbind(0, data.selected))
-        variable.names <- c("dependent", forest$independent.variable.names)
-      } else if (forest$dependent.varID >= ncol(data)) {
-        data.final <- data.matrix(cbind(data.selected, 0))
-        variable.names <- c(forest$independent.variable.names, "dependent")
-      } else {
-        data.final <- data.matrix(cbind(data.selected[, 1:forest$dependent.varID], 
-                                        0, 
-                                        data.selected[, (forest$dependent.varID+2):ncol(data.selected)]))
-        variable.names <- c(forest$independent.variable.names[1:forest$dependent.varID], 
-                            "dependent", 
-                            forest$independent.variable.names[(forest$dependent.varID+1):length(forest$independent.variable.names)])
-      }
-    }
+    data.final <- data.matrix(cbind(0, data.selected))
+    variable.names <- c("dependent", forest$independent.variable.names)
   }
 
-  
   ## If gwa mode, add snp variable names
   if (gwa.mode) {
     variable.names <- c(variable.names, snp.names)
@@ -146,10 +106,6 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
   if (any(is.na(data.final))) {
     stop("Missing values in data.")
   }
-  
-  if (sum(!(forest$independent.variable.names %in% variable.names)) > 0) {
-    stop("Error: One or more independent variables not found in data.")
-  }
 
   ## Num threads
   ## Default 0 -> detect from system in C++.
@@ -159,9 +115,20 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
     stop("Error: Invalid value for num.threads")
   }
 
+  ## Memory mode
+  if (is.null(memory.mode) | memory.mode == "double") {
+    memory.mode <- 0
+  } else if (memory.mode == "float") {
+    memory.mode <- 1
+  } else if (memory.mode == "char") {
+    memory.mode <- 2
+  } else {
+    stop("Error: Unknown memory mode.")
+  }
+
   ## Seed
   if (is.null(seed)) {
-    seed <- runif(1 , 0, .Machine$integer.max)
+    seed <- 0
   }
 
   if (forest$treetype == "Classification") {
@@ -181,7 +148,7 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
   mtry <- 0
   importance <- 0
   min.node.size <- 0
-  split.select.weights <- list(c(0, 0))
+  split.select.weights <- c(0, 0)
   use.split.select.weights <- FALSE
   always.split.variables <- c("0", "0")
   use.always.split.variables <- FALSE
@@ -190,50 +157,35 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
   write.forest <- FALSE
   replace <- TRUE
   probability <- FALSE
-  unordered.factor.variables <- c("0", "0")
-  use.unordered.factor.variables <- FALSE
-  save.memory <- FALSE
   splitrule <- 1
-  case.weights <- c(0, 0)
-  use.case.weights <- FALSE
-  keep.inbag <- FALSE
-  sample.fraction <- 1
-  
+
   ## Call Ranger
-  result <- rangerCpp(treetype, dependent.variable.name, data.final, variable.names, mtry,
-                      forest$num.trees, verbose, seed, num.threads, write.forest, importance,
-                      min.node.size, split.select.weights, use.split.select.weights,
-                      always.split.variables, use.always.split.variables,
-                      status.variable.name, prediction.mode, forest, sparse.data, replace, probability,
-                      unordered.factor.variables, use.unordered.factor.variables, save.memory, splitrule, 
-                      case.weights, use.case.weights, predict.all, keep.inbag, sample.fraction)
+  result <- rangerCpp(treetype, dependent.variable.name, memory.mode, data.final, variable.names, mtry,
+                       forest$num.trees, verbose, seed, num.threads, write.forest, importance,
+                       min.node.size, split.select.weights, use.split.select.weights,
+                       always.split.variables, use.always.split.variables,
+                       status.variable.name, prediction.mode, forest, sparse.data, 
+                       replace, probability, splitrule)
 
   if (length(result) == 0) {
-    stop("User interrupt or internal error.")
+    stop("Internal error.")
   }
-  
+
   ## Prepare results
   result$predictions <- drop(do.call(rbind, result$predictions))
   result$num.samples <- nrow(data.final)
   result$treetype <- forest$treetype
-  
-  if (forest$treetype == "Classification" & !is.null(forest$levels)) {
-    if (!predict.all) {
-      result$predictions <- factor(result$predictions, levels = 1:length(forest$levels),
-                                   labels = forest$levels)
-    }
+
+  if (forest$treetype == "Classification") {
+    result$predictions <- factor(result$predictions, levels = 1:length(forest$levels),
+                                 labels = forest$levels)
   } else if (forest$treetype == "Survival") {
     result$unique.death.times <- forest$unique.death.times
     result$chf <- result$predictions
     result$predictions <- NULL
     result$survival <- exp(-result$chf)
-  } else if (forest$treetype == "Probability estimation" & !is.null(forest$levels)) {
-    if (is.matrix(result$predictions)) {
-      colnames(result$predictions) <- forest$levels
-    } else {
-      names(result$predictions) <- forest$levels
-    }
-    
+  } else if (forest$treetype == "Probability estimation") {
+    colnames(result$predictions) <- forest$levels
   }
 
   class(result) <- "ranger.prediction"
@@ -241,16 +193,13 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
 }
 
 ##' Prediction with new data and a saved forest from Ranger.
-##' 
-##' For classification and predict.all = TRUE, a matrix of factor levels is returned. 
-##' To retrieve the corresponding factor levels, use rf$forest$levels, if rf is the ranger object.
 ##'
 ##' @title Ranger prediction
 ##' @param object Ranger \code{ranger} object.
 ##' @param data New test data of class \code{data.frame} or \code{gwaa.data} (GenABEL).
-##' @param predict.all Return a matrix with individual predictions for each tree instead of aggregated predictions for all trees (classification and regression only).
 ##' @param seed Random seed used in Ranger.
 ##' @param num.threads Number of threads. Default is number of CPUs available.
+##' @param memory.mode Memory mode, one of 'double', 'float', 'char'.
 ##' @param verbose Verbose output on or off.
 ##' @param ... further arguments passed to or from other methods.
 ##' @return Object of class \code{ranger.prediction} with elements
@@ -267,12 +216,11 @@ predict.ranger.forest <- function(object, data, predict.all = FALSE,
 ##' @seealso \code{\link{ranger}}
 ##' @author Marvin N. Wright
 ##' @export
-predict.ranger <- function(object, data, predict.all = FALSE,
-                           seed = NULL, num.threads = NULL,
-                           verbose = TRUE, ...) {
+predict.ranger <- function(object, data, seed = NULL, num.threads = NULL,
+                            memory.mode = "double", verbose = TRUE, ...) {
   forest <- object$forest
   if (is.null(forest)) {
     stop("Error: No saved forest in ranger object. Please set write.forest to TRUE when calling ranger.")
   }
-  predict(forest, data, predict.all, seed, num.threads, verbose)
+  predict(forest, data, seed, num.threads, memory.mode, verbose)
 }
