@@ -1,30 +1,30 @@
 /*-------------------------------------------------------------------------------
- This file is part of Ranger.
+This file is part of Ranger.
+    
+Ranger is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
- Ranger is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
+Ranger is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
- Ranger is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+You should have received a copy of the GNU General Public License
+along with Ranger. If not, see <http://www.gnu.org/licenses/>.
 
- You should have received a copy of the GNU General Public License
- along with Ranger. If not, see <http://www.gnu.org/licenses/>.
+Written by: 
 
- Written by:
+Marvin N. Wright
+Institut für Medizinische Biometrie und Statistik
+Universität zu Lübeck
+Ratzeburger Allee 160
+23562 Lübeck 
 
- Marvin N. Wright
- Institut für Medizinische Biometrie und Statistik
- Universität zu Lübeck
- Ratzeburger Allee 160
- 23562 Lübeck
-
- http://www.imbs-luebeck.de
- wright@imbs.uni-luebeck.de
- #-------------------------------------------------------------------------------*/
+http://www.imbs-luebeck.de
+wright@imbs.uni-luebeck.de
+#-------------------------------------------------------------------------------*/
 
 #include <set>
 #include <algorithm>
@@ -37,7 +37,7 @@
 #include "Data.h"
 
 ForestSurvival::ForestSurvival() :
-    status_varID(0), response_timepointIDs(0) {
+    status_varID(0) {
 }
 
 ForestSurvival::~ForestSurvival() {
@@ -47,19 +47,17 @@ void ForestSurvival::loadForest(size_t dependent_varID, size_t num_trees,
     std::vector<std::vector<std::vector<size_t>> >& forest_child_nodeIDs,
     std::vector<std::vector<size_t>>& forest_split_varIDs, std::vector<std::vector<double>>& forest_split_values,
     size_t status_varID, std::vector<std::vector<std::vector<double>> >& forest_chf,
-    std::vector<double>& unique_timepoints, std::vector<bool>& is_ordered_variable) {
+    std::vector<double>& unique_timepoints) {
 
   this->dependent_varID = dependent_varID;
   this->status_varID = status_varID;
   this->num_trees = num_trees;
-  this->is_ordered_variable = is_ordered_variable;
-  this->unique_timepoints = unique_timepoints;
 
   // Create trees
   trees.reserve(num_trees);
   for (size_t i = 0; i < num_trees; ++i) {
     Tree* tree = new TreeSurvival(forest_child_nodeIDs[i], forest_split_varIDs[i], forest_split_values[i],
-        forest_chf[i], &this->unique_timepoints, &response_timepointIDs, &this->is_ordered_variable);
+        forest_chf[i], &unique_timepoints);
     trees.push_back(tree);
   }
 
@@ -78,8 +76,8 @@ void ForestSurvival::initInternal(std::string status_variable_name) {
 
   // If mtry not set, use floored square root of number of independent variables.
   if (mtry == 0) {
-    unsigned long temp = ceil(sqrt((double) (num_variables - 2)));
-    mtry = std::max((unsigned long) 1, temp);
+    int temp = ceil(sqrt(num_variables - 2));
+    mtry = std::max(1, temp);
   }
 
   // Set minimal node size
@@ -90,36 +88,27 @@ void ForestSurvival::initInternal(std::string status_variable_name) {
   // Create unique timepoints
   std::set<double> unique_timepoint_set;
   for (size_t i = 0; i < num_samples; ++i) {
-    unique_timepoint_set.insert(data->get(i, dependent_varID));
+    if (data->get(i, status_varID) == 1) {
+      unique_timepoint_set.insert(data->get(i, dependent_varID));
+    }
   }
   unique_timepoints.reserve(unique_timepoint_set.size());
   for (auto& t : unique_timepoint_set) {
     unique_timepoints.push_back(t);
   }
-
-  // Create response_timepointIDs
-  if (!prediction_mode) {
-    for (size_t i = 0; i < num_samples; ++i) {
-      double value = data->get(i, dependent_varID);
-
-      // If timepoint is already in unique_timepoints, use ID. Else create a new one.
-      uint timepointID = find(unique_timepoints.begin(), unique_timepoints.end(), value) - unique_timepoints.begin();
-      response_timepointIDs.push_back(timepointID);
-    }
-  }
 }
 
 void ForestSurvival::growInternal() {
   trees.reserve(num_trees);
   for (size_t i = 0; i < num_trees; ++i) {
-    trees.push_back(new TreeSurvival(&unique_timepoints, status_varID, &response_timepointIDs));
+    trees.push_back(new TreeSurvival(&unique_timepoints, status_varID));
   }
 }
 
 void ForestSurvival::predictInternal() {
 
-  size_t num_prediction_samples = data->getNumRows();
-  size_t num_timepoints = ((TreeSurvival*) trees[0])->getPrediction(0).size();
+  size_t num_prediction_samples = trees[0]->getPredictions().size();
+  size_t num_timepoints = trees[0]->getPredictions()[0].size();
 
   predictions.reserve(num_prediction_samples);
 
@@ -131,9 +120,9 @@ void ForestSurvival::predictInternal() {
     for (size_t j = 0; j < num_timepoints; ++j) {
       double sample_time_prediction = 0;
       for (size_t k = 0; k < num_trees; ++k) {
-        sample_time_prediction += ((TreeSurvival*) trees[k])->getPrediction(i)[j];
+        sample_time_prediction += trees[k]->getPredictions()[i][j];
       }
-      sample_prediction.push_back(sample_time_prediction / num_trees);
+      sample_prediction.push_back(sample_time_prediction/num_trees);
     }
     predictions.push_back(sample_prediction);
   }
@@ -142,7 +131,7 @@ void ForestSurvival::predictInternal() {
 
 void ForestSurvival::computePredictionErrorInternal() {
 
-  size_t num_timepoints = ((TreeSurvival*) trees[0])->getPrediction(0).size();
+  size_t num_timepoints = trees[0]->getPredictions()[0].size();
 
   // For each sample sum over trees where sample is OOB
   std::vector<size_t> samples_oob_count;
@@ -156,7 +145,7 @@ void ForestSurvival::computePredictionErrorInternal() {
   for (size_t tree_idx = 0; tree_idx < num_trees; ++tree_idx) {
     for (size_t sample_idx = 0; sample_idx < trees[tree_idx]->getNumSamplesOob(); ++sample_idx) {
       size_t sampleID = trees[tree_idx]->getOobSampleIDs()[sample_idx];
-      std::vector<double> tree_sample_chf = ((TreeSurvival*) trees[tree_idx])->getPrediction(sample_idx);
+      std::vector<double> tree_sample_chf = trees[tree_idx]->getPredictions()[sample_idx];
 
       for (size_t time_idx = 0; time_idx < tree_sample_chf.size(); ++time_idx) {
         predictions[sampleID][time_idx] += tree_sample_chf[time_idx];
@@ -169,14 +158,12 @@ void ForestSurvival::computePredictionErrorInternal() {
   std::vector<double> sum_chf;
   sum_chf.reserve(predictions.size());
   for (size_t i = 0; i < predictions.size(); ++i) {
-    if (samples_oob_count[i] > 0) {
-      double sum = 0;
-      for (size_t j = 0; j < predictions[i].size(); ++j) {
-        predictions[i][j] /= samples_oob_count[i];
-        sum += predictions[i][j];
-      }
-      sum_chf.push_back(sum);
+    double sum = 0;
+    for (size_t j = 0; j < predictions[i].size(); ++j) {
+      predictions[i][j] /= samples_oob_count[i];
+      sum += predictions[i][j];
     }
+    sum_chf.push_back(sum);
   }
 
   // Use empty vector to use all samples in computeConcordanceIndex
@@ -314,8 +301,7 @@ void ForestSurvival::loadFromFileInternal(std::ifstream& infile) {
     }
 
     // Create tree
-    Tree* tree = new TreeSurvival(child_nodeIDs, split_varIDs, split_values, chf, &unique_timepoints,
-        &response_timepointIDs, &is_ordered_variable);
+    Tree* tree = new TreeSurvival(child_nodeIDs, split_varIDs, split_values, chf, &unique_timepoints);
     trees.push_back(tree);
   }
 }
