@@ -41,21 +41,17 @@ public:
   // Create from loaded forest
   TreeProbability(std::vector<std::vector<size_t>>& child_nodeIDs, std::vector<size_t>& split_varIDs,
       std::vector<double>& split_values, std::vector<double>* class_values, std::vector<uint>* response_classIDs,
-      std::vector<std::vector<double>>& terminal_class_counts, std::vector<bool>* is_ordered_variable);
+      std::vector<std::vector<double>>& terminal_class_counts);
 
   virtual ~TreeProbability();
 
   void initInternal();
 
+  void addPrediction(size_t nodeID, size_t sampleID);
   void addToTerminalNodes(size_t nodeID);
   void computePermutationImportanceInternal(std::vector<std::vector<size_t>>* permutations);
   void appendToFileInternal(std::ofstream& file);
 
-  const std::vector<double>& getPrediction(size_t sampleID) const {
-    size_t terminal_nodeID = prediction_terminal_nodeIDs[sampleID];
-    return (terminal_class_counts[terminal_nodeID]);
-  }
-
   const std::vector<std::vector<double>>& getTerminalClassCounts() const {
     return terminal_class_counts;
   }
@@ -68,22 +64,18 @@ private:
 
   // Called by splitNodeInternal(). Sets split_varIDs and split_values.
   bool findBestSplit(size_t nodeID, std::vector<size_t>& possible_split_varIDs);
-  void findBestSplitValueSmallQ(size_t nodeID, size_t varID, double sum_node, size_t num_samples_node,
-      double& best_value, size_t& best_varID, double& best_decrease);
-  void findBestSplitValueLargeQ(size_t nodeID, size_t varID, double sum_node, size_t num_samples_node,
-      double& best_value, size_t& best_varID, double& best_decrease);
-  void findBestSplitValueUnordered(size_t nodeID, size_t varID, double sum_node, size_t num_samples_node,
-      double& best_value, size_t& best_varID, double& best_decrease);
 
   void addImpurityImportance(size_t nodeID, size_t varID, double decrease);
 
+  void reservePredictionMemory(size_t num_predictions) {
+    predictions.resize(num_predictions, std::vector<double>());
+    for (size_t i = 0; i < num_predictions; ++i) {
+      predictions[i].resize(class_values->size(), 0);
+    }
+  }
+
   void cleanUpInternal() {
-    if (counter != 0) {
-      delete[] counter;
-    }
-    if (sums != 0) {
-      delete[] sums;
-    }
+    // Empty on purpose
   }
 
   // Classes of the dependent variable and classIDs for responses
@@ -93,9 +85,6 @@ private:
   // Class counts in terminal nodes. Empty for non-terminal nodes.
   std::vector<std::vector<double>> terminal_class_counts;
 
-  size_t* counter;
-  double* sums;
-
   DISALLOW_COPY_AND_ASSIGN(TreeProbability);
 };
 
