@@ -162,13 +162,13 @@ void drawWithoutReplacementKnuth(std::vector<size_t>& result, std::mt19937_64& r
 }
 
 void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64& random_number_generator,
-    std::vector<size_t>& indices, size_t num_samples, std::vector<double>& weights) {
+    std::vector<size_t>& indizes, size_t num_samples, std::vector<double>& weights) {
 
   result.reserve(num_samples);
 
   // Set all to not selected
   std::vector<bool> temp;
-  temp.resize(indices.size(), false);
+  temp.resize(indizes.size(), false);
 
   std::discrete_distribution<> weighted_dist(weights.begin(), weights.end());
   for (size_t i = 0; i < num_samples; ++i) {
@@ -177,27 +177,7 @@ void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64
       draw = weighted_dist(random_number_generator);
     } while (temp[draw]);
     temp[draw] = true;
-    result.push_back(indices[draw]);
-  }
-}
-
-void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64& random_number_generator,
-    size_t max_index, size_t num_samples, std::vector<double>& weights) {
-
-  result.reserve(num_samples);
-
-  // Set all to not selected
-  std::vector<bool> temp;
-  temp.resize(max_index + 1, false);
-
-  std::discrete_distribution<> weighted_dist(weights.begin(), weights.end());
-  for (size_t i = 0; i < num_samples; ++i) {
-    size_t draw;
-    do {
-      draw = weighted_dist(random_number_generator);
-    } while (temp[draw]);
-    temp[draw] = true;
-    result.push_back(draw);
+    result.push_back(indizes[draw]);
   }
 }
 
@@ -274,29 +254,19 @@ double computeConcordanceIndex(Data* data, std::vector<double>& sum_chf, size_t
 
 }
 
-std::string uintToString(uint number) {
-#if WIN_R_BUILD == 1
-  std::stringstream temp;
-  temp << number;
-  return temp.str();
-#else
-  return std::to_string(number);
-#endif
-}
-
 std::string beautifyTime(uint seconds) {
   std::string result;
 
   // Add seconds, minutes, hours, days if larger than zero
   uint out_seconds = (uint) seconds % 60;
-  result = uintToString(out_seconds) + " seconds";
+  result = std::to_string(out_seconds) + " seconds";
   uint out_minutes = (seconds / 60) % 60;
   if (seconds / 60 == 0) {
     return result;
   } else if (out_minutes == 1) {
     result = "1 minute, " + result;
   } else {
-    result = uintToString(out_minutes) + " minutes, " + result;
+    result = std::to_string(out_minutes) + " minutes, " + result;
   }
   uint out_hours = (seconds / 3600) % 24;
   if (seconds / 3600 == 0) {
@@ -304,7 +274,7 @@ std::string beautifyTime(uint seconds) {
   } else if (out_hours == 1) {
     result = "1 hour, " + result;
   } else {
-    result = uintToString(out_hours) + " hours, " + result;
+    result = std::to_string(out_hours) + " hours, " + result;
   }
   uint out_days = (seconds / 86400);
   if (out_days == 0) {
@@ -312,7 +282,7 @@ std::string beautifyTime(uint seconds) {
   } else if (out_days == 1) {
     result = "1 day, " + result;
   } else {
-    result = uintToString(out_days) + " days, " + result;
+    result = std::to_string(out_days) + " days, " + result;
   }
   return result;
 }
@@ -359,38 +329,3 @@ void shuffleAndSplit(std::vector<size_t>& first_part, std::vector<size_t>& secon
   first_part.resize(n_first);
 }
 
-std::string checkUnorderedVariables(Data* data, std::vector<std::string> unordered_variable_names) {
-  size_t num_rows = data->getNumRows();
-  std::vector<size_t> sampleIDs(num_rows);
-  std::iota(sampleIDs.begin(), sampleIDs.end(), 0);
-
-  // Check for all unordered variables
-  for (auto& variable_name : unordered_variable_names) {
-    size_t varID = data->getVariableID(variable_name);
-    std::vector<double> all_values;
-    data->getAllValues(all_values, sampleIDs, varID);
-
-    // Check level count
-    size_t max_level_count = 8 * sizeof(size_t) - 1;
-    if (all_values.size() > max_level_count) {
-      return "Too many levels in unordered categorical variable " + variable_name + ". Only "
-          + uintToString(max_level_count) + " levels allowed on this system.";
-    }
-
-    // Check positive integers
-    if (!checkPositiveIntegers(all_values)) {
-      return "Not all values in unordered categorical variable " + variable_name + " are positive integers.";
-    }
-  }
-  return "";
-}
-
-bool checkPositiveIntegers(std::vector<double>& all_values) {
-  for (auto& value : all_values) {
-    if (value < 1 || !(floor(value) == value)) {
-      return false;
-    }
-  }
-  return true;
-}
-
