@@ -1,30 +1,30 @@
 /*-------------------------------------------------------------------------------
- This file is part of Ranger.
+This file is part of Ranger.
+    
+Ranger is free software: you can redistribute it and/or modify
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation, either version 3 of the License, or
+(at your option) any later version.
 
- Ranger is free software: you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation, either version 3 of the License, or
- (at your option) any later version.
+Ranger is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+GNU General Public License for more details.
 
- Ranger is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- GNU General Public License for more details.
+You should have received a copy of the GNU General Public License
+along with Ranger. If not, see <http://www.gnu.org/licenses/>.
 
- You should have received a copy of the GNU General Public License
- along with Ranger. If not, see <http://www.gnu.org/licenses/>.
+Written by: 
 
- Written by:
+Marvin N. Wright
+Institut für Medizinische Biometrie und Statistik
+Universität zu Lübeck
+Ratzeburger Allee 160
+23562 Lübeck 
 
- Marvin N. Wright
- Institut für Medizinische Biometrie und Statistik
- Universität zu Lübeck
- Ratzeburger Allee 160
- 23562 Lübeck
-
- http://www.imbs-luebeck.de
- wright@imbs.uni-luebeck.de
- #-------------------------------------------------------------------------------*/
+http://www.imbs-luebeck.de
+wright@imbs.uni-luebeck.de
+#-------------------------------------------------------------------------------*/
 
 #ifndef UTILITY_H_
 #define UTILITY_H_
@@ -37,10 +37,6 @@
 #include <unordered_set>
 #include <unordered_map>
 
-#ifdef R_BUILD
-#include <Rinternals.h>
-#endif
-
 #include "globals.h"
 #include "Data.h"
 
@@ -65,22 +61,13 @@ void equalSplit(std::vector<uint>& result, uint start, uint end, uint num_parts)
  * @param file ofstream object to write to.
  */
 template<typename T>
-inline void saveVector1D(std::vector<T>& vector, std::ofstream& file) {
-  // Save length
-  size_t length = vector.size();
-  file.write((char*) &length, sizeof(length));
-  file.write((char*) vector.data(), length * sizeof(T));
-}
-
-template<>
-inline void saveVector1D(std::vector<bool>& vector, std::ofstream& file) {
+void saveVector1D(std::vector<T>& vector, std::ofstream& file) {
   // Save length
   size_t length = vector.size();
   file.write((char*) &length, sizeof(length));
 
   // Save vector
-  for (size_t i = 0; i < vector.size(); ++i) {
-    bool v = vector[i];
+  for (auto& v : vector) {
     file.write((char*) &v, sizeof(v));
   }
 }
@@ -91,23 +78,14 @@ inline void saveVector1D(std::vector<bool>& vector, std::ofstream& file) {
  * @param file ifstream object to read from.
  */
 template<typename T>
-inline void readVector1D(std::vector<T>& result, std::ifstream& file) {
-  // Read length
-  size_t length;
-  file.read((char*) &length, sizeof(length));
-  result.resize(length);
-  file.read((char*) result.data(), length * sizeof(T));
-}
-
-template<>
-inline void readVector1D(std::vector<bool>& result, std::ifstream& file) {
+void readVector1D(std::vector<T>& result, std::ifstream& file) {
   // Read length
   size_t length;
   file.read((char*) &length, sizeof(length));
 
   // Read vector.
   for (size_t i = 0; i < length; ++i) {
-    bool temp;
+    T temp;
     file.read((char*) &temp, sizeof(temp));
     result.push_back(temp);
   }
@@ -119,15 +97,21 @@ inline void readVector1D(std::vector<bool>& result, std::ifstream& file) {
  * @param file ofstream object to write to.
  */
 template<typename T>
-inline void saveVector2D(std::vector<std::vector<T>>& vector, std::ofstream& file) {
+void saveVector2D(std::vector<std::vector<T>>& vector, std::ofstream& file) {
   // Save length of first dim
   size_t length = vector.size();
   file.write((char*) &length, sizeof(length));
 
   // Save outer vector
   for (auto& inner_vector : vector) {
+    // Save length of inner vector
+    size_t length_inner = inner_vector.size();
+    file.write((char*) &length_inner, sizeof(length_inner));
+
     // Save inner vector
-    saveVector1D(inner_vector, file);
+    for (auto& element : inner_vector) {
+      file.write((char*) &element, sizeof(element));
+    }
   }
 }
 
@@ -137,16 +121,25 @@ inline void saveVector2D(std::vector<std::vector<T>>& vector, std::ofstream& fil
  * @param file ifstream object to read from.
  */
 template<typename T>
-inline void readVector2D(std::vector<std::vector<T>>& result, std::ifstream& file) {
+void readVector2D(std::vector<std::vector<T>>& result, std::ifstream& file) {
   // Read length of first dim
   size_t length;
   file.read((char*) &length, sizeof(length));
-  result.resize(length);
 
   // Read outer vector
   for (size_t i = 0; i < length; ++i) {
+    // Read length of inner vector
+    size_t length_inner;
+    file.read((char*) &length_inner, sizeof(length_inner));
+
     // Read inner vector
-    readVector1D(result[i], file);
+    std::vector<T> temp_vector;
+    for (size_t j = 0; j < length_inner; ++j) {
+      T temp;
+      file.read((char*) &temp, sizeof(temp));
+      temp_vector.push_back(temp);
+    }
+    result.push_back(temp_vector);
   }
 }
 
@@ -192,7 +185,7 @@ void drawWithoutReplacementKnuth(std::vector<size_t>& result, std::mt19937_64& r
     std::vector<size_t>& skip, size_t num_samples);
 
 /**
- * Draw random numers without replacement and with weighted probabilites from vector of indices.
+ * Draw random numers without replacement and with weighted probabilites.
  * @param result Vector to add results to. Will not be cleaned before filling.
  * @param random_number_generator Random number generator
  * @param indices Vector with numbers to draw
@@ -202,17 +195,6 @@ void drawWithoutReplacementKnuth(std::vector<size_t>& result, std::mt19937_64& r
 void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64& random_number_generator,
     std::vector<size_t>& indices, size_t num_samples, std::vector<double>& weights);
 
-/**
- * Draw random numers without replacement and with weighted probabilites from 0..n-1.
- * @param result Vector to add results to. Will not be cleaned before filling.
- * @param random_number_generator Random number generator
- * @param max_index Maximum index to draw
- * @param num_samples Number of samples to draw
- * @param weights A weight for each element of indices
- */
-void drawWithoutReplacementWeighted(std::vector<size_t>& result, std::mt19937_64& random_number_generator,
-    size_t max_index, size_t num_samples, std::vector<double>& weights);
-
 /**
  * Returns the most frequent class index of a vector with counts for the classes. Returns a random class if counts are equal.
  * @param class_count Vector with class counts
@@ -267,13 +249,6 @@ double mostFrequentValue(std::unordered_map<double, size_t>& class_count, std::m
 double computeConcordanceIndex(Data* data, std::vector<double>& sum_chf, size_t dependent_varID, size_t status_varID,
     std::vector<size_t>& sample_IDs);
 
-/**
- * Convert a unsigned integer to string
- * @param number Number to convert
- * @return Converted number as string
- */
-std::string uintToString(uint number);
-
 /**
  * Beautify output of time.
  * @param seconds Time in seconds
@@ -298,7 +273,7 @@ size_t roundToNextMultiple(size_t value, uint multiple);
 void splitString(std::vector<std::string>& result, std::string input, char split_char);
 
 /**
- * Create numbers from 0 to n_all-1, shuffle and split in two parts.
+ * Create numbers from 0 to n_all-1, shuffle and split in two parts
  * @param first_part First part
  * @param second_part Second part
  * @param n_all Number elements
@@ -308,30 +283,4 @@ void splitString(std::vector<std::string>& result, std::string input, char split
 void shuffleAndSplit(std::vector<size_t>& first_part, std::vector<size_t>& second_part, size_t n_all, size_t n_first,
     std::mt19937_64 random_number_generator);
 
-/**
- * Check if not too many factor levels and all values in unordered categorical variables are positive integers.
- * @param data Pointer to data object
- * @param unordered_variable_names Names of unordered variables
- * @return Error message, empty if no problem occured
- */
-std::string checkUnorderedVariables(Data* data, std::vector<std::string> unordered_variable_names);
-
-/**
- * Check if all values in double vector are positive integers.
- * @param all_values Double vector to check
- * @return True if all values are positive integers
- */
-bool checkPositiveIntegers(std::vector<double>& all_values);
-
-// User interrupt from R
-#ifdef R_BUILD
-static void chkIntFn(void *dummy) {
-  R_CheckUserInterrupt();
-}
-
-inline bool checkInterrupt() {
-  return (R_ToplevelExec(chkIntFn, NULL) == FALSE);
-}
-#endif
-
 #endif /* UTILITY_H_ */
